Delaware State Courts Opinions and Orders

Courts

Courts

Courts

Citizen Help

Citizen Help

Citizen Help

Opinions

Opinions

Opinions

Calendars

Calendars

Calendars

Forms

Forms

Forms

Rules

Rules

Rules

Jury

Jury

Jury

eFiling

eFiling

eFiling

Non-Judicial Agencies

Non-Judicial Agencies

Non-Judicial Agencies

General Information

General Information

General Information

home | feedback |
| Search:

All Courts
› | Civil
› | Criminal
Supreme
› | Civil
› | Criminal
Chancery
Superior
› | CCLD
› | Civil
› | Criminal
Common Pleas
› | Civil
› | Criminal
Justice of the Peace
| Get Acrobat Reader
Superior Court Opinions and Orders
Please note: These electronic orders may contain computer-generated errors or other deviations from the official printed versions. In case of discrepancies between the print and electronic versions of orders, the print version controls. In case of discrepancies between the print and electronic versions of orders and any later official version of them, the later version controls. Please also note: There are currently issues with some of the documents not opening when using the Chrome browser. If you cannot open a document and are using Chrome, please try using a different browser.
| Year: | Open Document in New Window |
Search For: |  |
368 files found, based on group and search criteria.
1 2 3 4 5 6 7 8
Date | Parties/Caption | Number | Court | Judicial Officer* | Description
7/24/14 | State of Delaware v. Gillis. | 1402018635 | Superior | Johnston J. | Memorandum Opinion. Defendant’s Motion to Suppress—DENIED.
7/22/14 | Brown v. Dover Downs Casino. | 13A-12-001 | Superior | Young J. | Order. Appellant’s Appeal From the Unemployment Insurance Appeal Board—AFFIRMED.
7/22/14 | Wood v. Collison, et al. | 14C-04-264 | Superior | Rocanelli J. | Opinion. Plaintiff’s Motion for an Emergency Injunction—DENIED.
7/21/14 | Dippold Marble & Granite, Inc. v. Harleysville Mutual Insurance Co. | 12C-09-021 | Superior | Young J. | Order. Defendant’s Motion to Dismiss—DENIED. Defendant’s Motion In Limine to Limit Value of Plaintiff’s Damages—DENIED.
7/18/14 | Tucker v. Unemployment Insurance Appeal Board. | 13A-12-003 | Superior | Streett J. | Opinion. Appellant’s Appeal From Unemployment Insurance Appeal Board Decision—REVERSED and REMANDED.
7/18/14 | Vaughan v. Firestone Hotel Group, Inc. | 13A-10-012 | Superior | Cooch R.J. | Order. Appellant’s Appeal From Industrial Accident Board Decision—AFFIRMED.
7/17/14 | Fleury v. Unemployment Insurance Appeal Board. | 14A-03-003 | Superior | Young J. | Order. Appellant’s Appeal From the Unemployment Insurance Appeal Board—REVERSED.
7/17/14 | State of Delaware v. Niyala. | 131000634 | Superior | Streett J. | Opinion. Defendant’s Motion to Suppress—GRANTED.
7/16/14 | Mitchell v. EMS, Inc. | 13C-02-224 | Superior | Wallace J. | Memorandum Opinion and Order. Employers Insurance of Wassau’s Motion to Intervene—GRANTED.
7/16/14 | Northpointe Holdings, Inc. v. Nationwide Emerging Managers, LLC, et al. / Nationwide Emerging Managers, LLC v. Northpointe Capital, LLC, et al. | 09C-11-141 | Superior | Rocanelli J. | Decision After Trial.
7/15/14 | State of Delaware v. Guess. | 1111020337 | Superior | Scott J. | Order. Defendant’s Motion for Postconviction Relief—DENIED.
7/14/14 | Lawson v. Delaware Department of Transportation, et al. | 14C-01-020 | Superior | Johnston J. | Order. Plaintiffs’ Application for Certification of an Interlocutory Appeal—DENIED.
7/14/14 | Santiago v. Lindvall. | 13C-07-205 | Superior | Cooch R.J. | Order. Defendant's Motion for Costs—DENIED.
7/14/14 | Walls v. Phelps, et al. | 12M-04-115 | Superior | Johnston J. | Order. Plaintiff’s Motion Under Rule 60(b)(6), Rule 112(a), and 10 Del. C. § 8804(b)—DENIED.
7/11/14 | Murphy & Landon, P.A. v. Pernic. | 13A-03-012 | Superior | Wharton J. | Opinion and Order. Appellant’s Appeal From Unemployment Insurance Appeal Board Decision—AFFIRMED.
7/9/14 | Furman v. Delaware Department of Transportation, et al. | 10C-10-164 | Superior | Scott J. | Order. Third-Party Defendant Scottsdale Indemnity Co.’s Motion to Dismiss—GRANTED.
7/9/14 | State of Delaware v. Phillips. | 1210013321 | Superior | Scott J. | Order. State’s Motion In Limine to Admit Evidence of Forfeiture by Wrongdoing Pursuant to D.R.E. 804(b)(6)—GRANTED.
7/8/14 | Jones v. The Hertz Corp., et al. | 13A-07-006 | Superior | Cooch R.J. | Opinion. Plaintiff Below/Appellant’s Appeal From a Decision of the Court of Common Pleas—AFFIRMED.
7/8/14 | Smith v. Delaware State Police, et al. | 12C-01-016 | Superior | Young J. | Order. Defendants’ Motion for Summary Judgment—GRANTED.
7/8/14 | State of Delaware v. Barksdale. | 1401017199 | Superior | Wallace J. | Order. Commissioner’s Report and Recommendation Adopted. Petitioner/Defendant's Petition for a Writ of Habeas Corpus—DENIED.
7/7/14 | State of Delaware v. Adgate. | 1401000712 | Superior | Young J. | Order. Defendant’s Motion to Dismiss—DENIED. Defendant’s Motion for Bill of Particulars—DENIED. Defendant’s Motion for a Deberry Instruction—GRANTED.
7/3/14 | Heglund v. AFL Network Services. | 13A-11-003 | Superior | Rocanelli J. | Memorandum Opinion. Appellant’s Appeal From Industrial Accident Board Decision—REVERSED, IN PART and REMANDED.
7/3/14 | State of Delaware v. Wonnum. | 30206697DI | Superior | Cooch R.J. | Order. Defendant’s Second Motion for Postconviction Relief—DENIED.
7/2/14 | State of Delaware v. McLaughlin. | 1104021773 | Superior | Rocanelli J. | Memorandum Opinion. Defendant’s Motion for Postconviction Relief—DENIED. Counsel's Motion to Withdraw—GRANTED.
7/1/14 | State of Delaware v. Dennis. | 1109010347 | Superior | Graves R.J. | Letter Opinion and Order. Defendant’s Motion for Postconviction Relief—DENIED. Counsel's Motion to Withdraw—GRANTED.
6/30/14 | Ali v. Beechcraft Corp., et al. | 11C-12-253 | Superior | Silverman J. | Order. Defendant Beechcraft Corporation’s Motion to Dismiss for Lack of Personal Jurisdiction—GRANTED.
6/30/14 | Bilski v. Board of Medical Licensure and Discipline of the State of Delaware. | 13A-10-005 | Superior | Medinilla J. | Opinion. Appellant’s Appeal of the Decision and Final Public Order of the Board of Medical Licensure and Discipline of the State of Delaware—AFFIRMED.
6/30/14 | Elliott v. State of Delaware. | 13A-08-008 | Superior | Streett J. | Opinion. Appellant's Appeal From Industrial Accident Board Decision—AFFIRMED.
6/30/14 | Haden v. Bethany Beach Police Department, et al. | 13A-11-003 | Superior | Stokes J. | Opinion and Order. Plaintiff’s Motion to Amend the Notice of Appeal to a Writ of Certiorari—DENIED.
6/30/14 | In the Matter of Lou Fieni. | 14M-01-046 | Superior | Slights J. | Order. Pro Se Request for Prompt Production of Records—DENIED.
6/30/14 | Lawson v. Delaware Department of Transportation, et al. | 14C-01-020 | Superior | Johnston J. | Order. Plaintiffs’ Motion for Reargument—DENIED.
6/30/14 | Louis v. Christiana Care Health Services, Inc. | 13C-02-240 | Superior | Wharton J. | Opinion and Order. Defendant’s Motion to Dismiss—GRANTED.
6/30/14 | Ocwen Loan Servicing, LLC v. HSBC Bank USA, National Association, et al. | 10C-09-071 | Superior | Scott J. | Order. Defendant Regions Bank’s Renewed Motion for Summary Judgment—DENIED.
6/30/14 | Revell v. Simmons. | 13C-05-113 | Superior | Scott J. | Order. Plaintiffs’ Motion for Leave to Amend the Complaint—DENIED.
6/30/14 | State of Delaware v. Dillard. | 1210011253 | Superior | Medinilla J. | Opinion. Defendant’s Motion for Postconviction Relief—DENIED. Counsel's Motion to Withdraw—GRANTED.
6/27/14 | State of Delaware v. Madison. | 1312014951 | Superior | Silverman J. | Order. Defendant’s Motion to Suppress—DENIED. Defendant’s Motion for Full Psychological Evaluation—DENIED. Defendant’s Motion to Reduce Bail—DENIED. Defendant’s Counsel’s Motion to Withdraw—DENIED.
6/25/14 | Purdie v. Unemployment Insurance Appeal Board. | 13A-11-005 | Superior | Cooch R.J. | Order. Appellant’s Appeal From Unemployment Insurance Appeal Board Decision—AFFIRMED.
6/25/14 | West IP Communications, Inc. v. Xactly Corporation. | 13C-06-052 | Superior | Streett J. | Opinion. Defendant’s Motion to Dismiss—GRANTED.
6/24/14 | Berry v. State of Delaware. | 14A-01-008 | Superior | Parkins J. | Order. Appellant’s Appeal From Industrial Accident Board Decision—AFFIRMED.
6/24/14 | Caballero, et al. v. Ford Motor Co., et al. | 11C-09-170 | Superior | Jurden J. | Opinion. Defendant Ford Motor Company’s Motion for Partial Summary Judgment—GRANTED.
6/24/14 | Deere & Co. v. Exelon Generation Acquisitions, LLC. | 13C-07-330 | Superior | Vaughn P.J. | Order. Plaintiff’s Motion For Reargument Pursuant to Rule 59(e)—DENIED.
6/24/14 | Progressive Gulf Insurance Co. v. Doughty. | 13C-07-038 | Superior | Vaughn P.J. | Opinion. Appellant’s Appeal From Decision of the Delaware Insurance Department Automobile Arbitration Panel—REVERSED.
6/24/14 | State of Delaware v. Parks. | 1307023034 | Superior | Wallace J. | Opinion. Defendant’s Motion to Suppress—DENIED IN PART, GRANTED IN PART. (Corrected July 8, 2014 to Remove Duplicate Footnote.)
6/23/14 | Walker v. City of New Castle, et al. | 13C-09-152 | Superior | Davis J. | Memorandum Opinion. Defendants City of New Castle and John Lloyd’s Motion for Judgment on the Pleadings—GRANTED.
6/20/14 | State of Delaware v. Stephenson. | 1212015998 | Superior | Parkins J. | Memorandum Opinion. State’s Motion to Exclude the Testimony of Dr. Rushing—GRANTED.
6/19/14 | Bugaj v. L & D Suzuki, et al. | 13A-10-003 | Superior | Vaughn P.J. | Order. Appellant’s Appeal From Decision of the Unemployment Insurance Appeal Board—AFFIRMED.
6/19/14 | State of Delaware v. Bryer. | 1008011916 | Superior | Vaughn P.J. | Opinion. Defendant's Motion to Dismiss Under Rule 48(b)—GRANTED.
6/18/14 | Garber v. Christiana Care Health Services, Inc., et al. | 14C-04-065 | Superior | Silverman J. | Order. Review of the Affidavits of Merit. Affidavits of Merit Comply with 18 Del. C. § 6853(a)(1) and (c).
6/18/14 | State of Delaware v. Demby. | 9412011308 | Superior | Cooch R.J. | Order. Defendant’s Third Motion for Postconviction Relief—DENIED. Defendant’s Motion for Trial Transcripts as well as to Proceed Informa Pauperis—DENIED.
6/17/14 | State of Delaware v. Lewis. | 1304026571 | Superior | Silverman J. | Order. Defendant’s Motion for Judgment of Acquittal—DENIED.
1 2 3 4 5 6 7 8
* C.=Chancellor or Commissioner; C.J.=Chief Justice or Chief Judge; J.=Justice or Judge; M.=Master; P.J.=President Judge; R.J.=Resident Judge; V.C.=Vice Chancellor
send an email containing a hyperlink to the selected document
| Year: | Open Document in New Window |
Search For: |  |